extensions [csv]

turtles-own [
  money       ;money of the workers
  oldmoney    ;money the workers had last month
  cost        ;the agents cost of life per month
  quality     ;the qualification of the agent (1-10)
  income      ;what the agents eanred last month
  pricewant   ;wage expectation for one contract (1 day of work)
  work        ;time until the current job is fulfilled
  internat    ;bool: true for international competitors
]
patches-own [
  rqual       ;required qulification needed for this contract (unused in some modes)
  offersp     ;list storing the prices of received offers
  offersq     ;list storing the qualification of received offers
  offersid    ;list storing the ids of the turtles that gave the offer
  costwant    ;cost expectation for this contract
  age         ;how long did the job exist
]

globals [
  reportlist  ;list containing csv values for data export
]


;; MAIN LOOP -------------

to go

  newjobs            ;the number of daily contracts is updated
  newagents          ;the size of the workforce is updated

  moveagents         ;agents move when they are looking for contracts

  makeoffers         ;agents bid on the contracts they found
  takeoffers         ;after a certain waiting time contracts select the best offer

  updatecontracts    ;contracts are updated

  calculateincome    ;agents calculate their income



  tick

  ;;stop simulation after specified number of ticks
  ;;note on time scale: 1 tick = 10 minutes -> 365 * 24 * 6 = 52560 ticks = 1 year
  if simulation-time != 0 [
  if ticks = simulation-time * 365 * 24 * 6
  [stop]
  ]

end



;; SETUP ------------------


to setup
  ca
  set reportlist []
  repeat workforce [maketurtle]

  ask patches[
    set pcolor white
    set offersp []
    set offersq []
    set offersid []
  ]


  reset-ticks
end

;; SUPPORT FUNCTIONS -------

to newjobs
  ;;changes the number of daily issued contrats

  if ticks mod 4380 = 0 [
    if d-contracts > 0[
      set contracts contracts + d-contracts
    ]

    if d-contracts < 0[
      set contracts contracts + d-contracts
      if contracts < 0 [set contracts 0]
      ]
  ]

end

to newagents
  ;;changes the size of the workforce
  if ticks mod 4380 = 0 [
    if d-workforce > 0 [
      repeat d-workforce [maketurtle]
    ]
    if d-workforce < 0 [
      repeat -1 * d-workforce [if any? turtles [ask one-of turtles [die]]]
    ]
  ]

end

to makeoffers

  if mode = "cheapest" or mode = "best"[
    ask turtles [
      if pcolor = gray [
        ask patch-here[
          set offersp lput [pricewant] of myself offersp
          set offersq lput [quality] of myself offersq
          set offersid lput [who] of myself offersid
        ]

      ]
    ]
  ]
  if mode = "minreq"[
    ask turtles [
      if pcolor = gray and quality >= [rqual] of patch-here [
        ask patch-here[
          set offersp lput [pricewant] of myself offersp
          set offersq lput [quality] of myself offersq
          set offersid lput [who] of myself offersid
        ]

      ]
    ]
  ]

  if mode = "fastest"[
    ask turtles [
      if pcolor = gray [
        ask patch-here[
          set offersp lput [pricewant] of myself offersp
          set offersq lput [quality] of myself offersq
          set offersid lput [who] of myself offersid
        ]

      ]
    ]
  ]

end

to takeoffers
  if mode = "cheapest"[
    ask patches with [length offersid >= 1 and age >= 144][
      let bestoffer position (min offersp) offersp
      set pcolor white
      ;makejob
      if is-turtle? turtle item bestoffer offersid[
        ask turtle item bestoffer offersid[
          set money money + pricewant
          set work 6 * 24

        ]
      ]
      set offersp []
      set offersq []
      set offersid []
      set age 0
    ]

  ]
  if mode = "minreq"[
    ask patches with [length offersid >= 1 and age >= 144][
      let bestoffer position (min offersp) offersp
      set pcolor white
      ;makejob
      if is-turtle? turtle item bestoffer offersid[
        ask turtle item bestoffer offersid[
          set money money + pricewant
          set work 6 * 24

        ]
      ]
      set offersp []
      set offersq []
      set offersid []
      set age 0
    ]

  ]
  if mode = "fastest"[
    ask patches with [length offersid >= 1][
      let bestoffer position (min offersid) offersid
      set pcolor white
      ;makejob
      let add costwant
      if is-turtle? turtle item bestoffer offersid[
        ask turtle item bestoffer offersid[
          set money money + add
          set work 6 * 24
        ]
      ]
      set offersp []
      set offersq []
      set offersid []
      set age 0


    ]
  ]
  if mode = "best"[

    ask patches with [length offersid >= 1 and age >= 144][
      let bestoffer position (max offersq) offersq
      set pcolor white
      ;makejob
      let add costwant
      if is-turtle? turtle item bestoffer offersid[
        ask turtle item bestoffer offersid[
          set money money + add
          set work 6 * 24
        ]
      ]
      set offersp []
      set offersq []
      set offersid []
      set age 0


    ]


  ]
end

to updatecontracts

  ask patches with [pcolor = gray][set age age + 1]

  if  random 100 < 100 * (contracts / (5 * 144))
  [
    repeat 5 [makejob]
  ]

end

to calculateincome

    if  (ticks + 1) mod 4320 = 0 [
    ask turtles [
      set money  money - cost
    ]
    calcincome

  ]
end


to maketurtle
  create-turtles 1[
    set size 2

    set internat false
    if random 100 < competition [set internat true]



    set cost random-normal 1000 100
    if internat [set cost competition-factor * cost]
    set quality random-float 10
    set pricewant random-normal (payment + payment-factor * quality) (0.1 * (payment + payment-factor * quality))
    if internat [set pricewant competition-factor * pricewant]
    set shape "person"
    setxy random-xcor random-ycor
    set color red
    if quality > 2  [set color orange]
    if quality > 4  [set color yellow]
    if quality > 6  [set color green]
    if quality > 8  [set color blue]
  ]

end




to makejob
  if any? patches with [pcolor = white][
  ask one-of patches with [pcolor = white] [
    set pcolor gray
    set rqual random 10
    set costwant random-normal (payment + payment-factor * rqual) (0.1 * (payment + payment-factor * rqual))
  ]]
end

to moveagents
  ask turtles [
    ifelse work = 0 [
      ;set shape "person"
      right 5 - random 11
      fd 1]
    [;set shape "computer workstation"

      set work work - 1]
  ]
end

to calcincome
  let oldt count turtles

  ask turtles[
    set income money - oldmoney
    set oldmoney money

  ]

  reporting

  ask turtles[

    if income < 0 [ if random 100 < quit-chance [
      die
      ]
    ]
  ]



  let newt count turtles





  repeat oldt - newt [maketurtle]

end


to standard-settings

  set simulation-time 3
  set contracts 500
  set workforce 1000
  set d-contracts 0
  set d-workforce 0
  set payment 150
  set payment-factor 5
  set competition 0
  set competition-factor 0.5
  set quit-chance 25



end

to reporting
  ask turtles[
    let intint 0
    if internat [set intint 1]

    set reportlist lput (list quality income intint ticks) reportlist
  ]


end

to save
  csv:to-file savefile reportlist

end
@#$#@#$#@
GRAPHICS-WINDOW
545
50
1260
766
-1
-1
7.0
1
10
1
1
1
0
1
1
1
-50
50
-50
50
0
0
1
ticks
30.0

BUTTON
185
50
248
83
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
185
110
248
143
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
100
175
270
220
mode
mode
"cheapest" "minreq" "fastest" "best"
0

SLIDER
100
280
272
313
contracts
contracts
0
1000
500.0
1
1
NIL
HORIZONTAL

SLIDER
100
325
272
358
workforce
workforce
0
1000
1000.0
1
1
NIL
HORIZONTAL

SLIDER
100
370
272
403
d-contracts
d-contracts
-50
50
0.0
1
1
NIL
HORIZONTAL

SLIDER
100
415
272
448
d-workforce
d-workforce
-100
100
0.0
1
1
NIL
HORIZONTAL

PLOT
1278
369
1641
519
Average Profit per Qualification
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"very high" 1.0 0 -13345367 true "" "plot mean [income] of turtles with [color = blue]"
"high" 1.0 0 -10899396 true "" "plot mean [income] of turtles with [color = green]"
"average" 1.0 0 -1184463 true "" "plot mean [income] of turtles with [color = yellow]"
"low" 1.0 0 -955883 true "" "plot mean [income] of turtles with [color = orange]"
"very low" 1.0 0 -2674135 true "" "plot mean [income] of turtles with [color = red]"

PLOT
1279
50
1640
200
Nr. of Workers per Qualification
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"very high" 1.0 0 -13345367 true "" "plot count turtles with [color = blue]"
"high" 1.0 0 -10899396 true "" "plot count turtles with [color = green]"
"average" 1.0 0 -1184463 true "" "plot count turtles with [color = yellow]"
"low" 1.0 0 -955883 true "" "plot count turtles with [color = orange]"
"very low" 1.0 0 -2674135 true "" "plot count turtles with [color = red]"

SLIDER
100
460
272
493
payment
payment
50
300
150.0
10
1
MU
HORIZONTAL

SLIDER
100
505
272
538
payment-factor
payment-factor
0
10
5.0
1
1
MU
HORIZONTAL

SLIDER
100
550
272
583
competition
competition
0
100
0.0
1
1
%
HORIZONTAL

PLOT
1280
210
1641
360
Average Workload per Qualification
NIL
NIL
0.0
10.0
0.0
0.1
true
true
"" ""
PENS
"very high" 1.0 0 -13345367 true "" "plot count turtles with [color = blue and work > 0] / count turtles with [color = blue]"
"high" 1.0 0 -10899396 true "" "plot count turtles with [color = green and work > 0] / count turtles with [color = green]"
"average " 1.0 0 -1184463 true "" "plot count turtles with [color = yellow and work > 0] / count turtles with [color = yellow]"
"low" 1.0 0 -955883 true "" "plot count turtles with [color = orange and work > 0] / count turtles with [color = orange]"
"very low" 1.0 0 -2674135 true "" "plot count turtles with [color = red and work > 0] / count turtles with [color = red]"

SLIDER
100
640
272
673
quit-chance
quit-chance
0
100
25.0
1
1
%
HORIZONTAL

SLIDER
280
50
460
83
simulation-time
simulation-time
0
10
3.0
1
1
years
HORIZONTAL

BUTTON
115
695
244
728
NIL
standard-settings
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
280
85
460
126
Time after which the simulation stops automatically (0 = never stop)
11
0.0
1

TEXTBOX
280
155
500
250
Mode how to distribute contracts:\ncheapest: Lowest offer is chosen\nminreq: Lowest offer is chosen, but each contract has a minial qualification requirement\nfastest: First offer is chosen\nbest: Highes qualification is chosen
11
0.0
1

TEXTBOX
285
290
435
308
Contracts issued per day
11
0.0
1

TEXTBOX
285
335
435
353
Initial size of the workforce
11
0.0
1

TEXTBOX
285
380
510
398
Change in daily contracts per month
11
0.0
1

TEXTBOX
285
420
515
438
Change in workforce per month
11
0.0
1

TEXTBOX
285
465
465
491
Minimal payment for one day of work
11
0.0
1

TEXTBOX
285
505
470
531
Additional payment for one day of work per level of qualification
11
0.0
1

TEXTBOX
285
555
480
581
Percentage of low cost competitors
11
0.0
1

SLIDER
100
595
272
628
competition-factor
competition-factor
0
1
0.5
0.1
1
NIL
HORIZONTAL

TEXTBOX
285
595
445
636
Reduction of competitors cost of living and income expectation
11
0.0
1

TEXTBOX
285
640
435
666
Chance to quit after a month with deficit
11
0.0
1

BUTTON
435
700
498
733
NIL
save
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
305
685
420
745
savefile
results.csv
1
0
String

PLOT
1285
550
1640
700
Available Contracts
NIL
NIL
0.0
10.0
0.0
0.1
true
true
"" ""
PENS
"Nr. per worker" 1.0 0 -16777216 true "" "plot count patches with [pcolor = gray] / count turtles"
"Avg. age" 1.0 0 -7500403 true "" "if any? patches with [pcolor = gray] [plot mean [age] of patches with [pcolor = gray] / 144]"

TEXTBOX
55
45
175
86
Press to initialize simulation ->
16
0.0
1

TEXTBOX
55
105
175
141
Press to start simulation ->
16
0.0
1

@#$#@#$#@
## WHAT IS IT?

The aim of this model is to simulate different variants of crowdworking.

## HOW IT WORKS

Agents have randomly assigned properties like qualification and wage expectation. They all compete on the same virtual crowdworking platform for contracts by placing offers once they found suitable contracts. The platform then selects the best offer and the agent is allowed to work and earn money. How this selection process works is governed by the selected mode. Workers who fail to turn a profit have a chance of being replaced by new random agents.

## HOW TO USE IT

For quick start, just press "Default Settings" -> "Setup" -> "Go". You can investigate different scenarios by changing the parameters.

## THINGS TO NOTICE

Since not all agents are equally suitable to be able to secure contract, a evolutionary process starts, where unfit agents are filtered out. After roughly one year of equlibration there will be a non-trivial distribution of agents, that is highly dependend on the used crowdworking variant.

## THINGS TO TRY

Try all the different modes to gain understanding which modes favour which agent qualification. Then you could reduce or increase the number of issued contracts to observe the effect on the profits. You can also introduce competition with lower cost of living and therefore lower wage expectations and see which of the crowdworking variants is more vulnerable to such competition.


## CREDITS AND REFERENCES

Copyright 2018 Georg Jäger.

![CC BY-NC-SA 3.0](http://ccl.northwestern.edu/images/creativecommons/byncsa.png)

This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 License.  To view a copy of this license, visit https://creativecommons.org/licenses/by-nc-sa/3.0/

Cite as:
Jäger, G.; Hofer, C.; Füllsack, M., "Understanding Crowdworking", Journal of Artificial Societies and Social Simulation ...... (2018)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

computer workstation
false
0
Rectangle -7500403 true true 60 45 240 180
Polygon -7500403 true true 90 180 105 195 135 195 135 210 165 210 165 195 195 195 210 180
Rectangle -16777216 true false 75 60 225 165
Rectangle -7500403 true true 45 210 255 255
Rectangle -10899396 true false 249 223 237 217
Line -16777216 false 60 225 120 225

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment-price" repetitions="1" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>set savefile (word price)
save</final>
    <metric>count turtles</metric>
    <steppedValueSet variable="price" first="50" step="50" last="250"/>
    <enumeratedValueSet variable="competition">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="quit-chance">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-workers">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-jobs">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-jobs">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mode">
      <value value="&quot;best&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-workers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="savefile">
      <value value="&quot;results_fastest2.csv&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="competition-factor">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pricefactor">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-jobs" repetitions="1" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>set savefile (word init-jobs)
save</final>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="price">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="competition">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="quit-chance">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-workers">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-jobs">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="init-jobs" first="300" step="100" last="700"/>
    <enumeratedValueSet variable="mode">
      <value value="&quot;cheapest&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-workers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="savefile">
      <value value="&quot;results_fastest2.csv&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="competition-factor">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pricefactor">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-pricefactor" repetitions="1" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>set savefile (word pricefactor)
save</final>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="price">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="competition">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="quit-chance">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-workers">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-jobs">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-jobs">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mode">
      <value value="&quot;cheapest&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-workers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="savefile">
      <value value="&quot;results_fastest2.csv&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="competition-factor">
      <value value="0.5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="pricefactor" first="1" step="2" last="9"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
1
@#$#@#$#@
